@@ -953,9 +953,6 @@ ControlledDhcpv6Srv::processConfig(isc::data::ConstElementPtr config) {
     // @todo This should be fixed.
     try {
         CfgMultiThreading::apply(CfgMgr::instance().getStagingCfg()->getDHCPMultiThreading());
-        if (MultiThreadingMgr::instance().getMode()) {
-            LOG_FATAL(dhcp6_logger, DHCP6_MULTI_THREADING_WARNING);
-        }
     } catch (const std::exception& ex) {
         err << "Error applying multi threading settings: "
             << ex.what();
