@@ -1,4 +1,4 @@
-// Copyright (C) 2015-2018 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2015-2019 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -235,7 +235,7 @@ public:
         }
     }
 
-    /// @brief Checks if IPv4 lease loaded from file is sanity checked.
+    /// @brief Checks if IPv6 lease loaded from file is sanity checked.
     ///
     /// This method writes a simple lease file with one lease in it,
     /// then sets sanity checks to tested level, then tries to load
@@ -249,10 +249,13 @@ public:
     /// @param sanity level of sanity checks
     /// @param exp_present is the lease expected to be loaded (true = yes)
     /// @param exp_id expected subnet-id of the loaded lease
+    /// @param prefix_len length of the prefix if the lease created should be
+    /// a PD lease. Defaults to 0.
     void sanityChecks6(std::string lease, SubnetID lease_id,
                        std::string subnet_txt, SubnetID subnet_id,
                        CfgConsistency::LeaseSanity sanity,
-                       bool exp_present, SubnetID exp_id) {
+                       bool exp_present, SubnetID exp_id,
+                       unsigned int prefix_len = 0) {
 
         // Create the subnet and add it to configuration.
         if (!subnet_txt.empty()) {
@@ -263,8 +266,9 @@ public:
         std::stringstream file_content;
 
         file_content << v6_hdr_ << lease << ",dd:de:ba:0d:1b:2e,"
-                     << "300,300," << static_cast<int>(lease_id)
-                     << ",150,0,8,0,0,0,,,1,\n";
+                     << "300,300," << static_cast<int>(lease_id) << ",150,"
+                     << (prefix_len > 0 ? Lease::TYPE_PD : Lease::TYPE_NA)
+                     << ",8," << prefix_len << ",0,0,,,1,\n";
 
         ASSERT_NO_THROW(CfgMgr::instance().getStagingCfg()->getConsistency()
                     ->setLeaseSanityCheck(sanity));
@@ -308,7 +312,7 @@ protected:
 };
 
 LeaseFileLoaderTest::LeaseFileLoaderTest()
-    : filename_(absolutePath("leases4.csv")), io_(filename_) {
+    : filename_(absolutePath("leases.csv")), io_(filename_) {
     CfgMgr::instance().clear();
 }
 
@@ -343,12 +347,12 @@ TEST_F(LeaseFileLoaderTest, loadWrite4) {
     std::string b_2 = "192.0.3.15,dd:de:ba:0d:1b:2e:3e:4f,0a:00:01:04,"
                       "100,135,7,0,0,,1,\n";
 
-    std::string c_1 = "192.0.2.3,,a:11:01:04,"
+    std::string c_1 = "192.0.2.3,,,"
                       "200,200,8,1,1,host.example.com,0,\n";
 
     // Create lease file with leases for 192.0.2.1, 192.0.3.15. The lease
-    // entry for the 192.0.2.3 is invalid (lacks HW address) and should
-    // be discarded.
+    // entry for the 192.0.2.3 is invalid (lacks HW address and client id)
+    // and should be discarded.
     test_str = v4_hdr_ + a_1 + b_1 + c_1 + b_2 + a_2;
     io_.writeFile(test_str);
 
@@ -456,6 +460,59 @@ TEST_F(LeaseFileLoaderTest, loadWrite4LeaseRemove) {
     }
 }
 
+// This test verifies that max-row-errors works correctly for
+// DHCPv4 lease files
+TEST_F(LeaseFileLoaderTest, maxRowErrors4) {
+    // We have 9 rows: 2 that are good, 7 that are flawed (too few fields).
+    std::vector<std::string> rows = {
+        "192.0.2.100,08:00:27:25:d3:f4,31:31:31:31,3600,1565356064,1,0,0,,0,\n",
+        "192.0.2.101,FF:FF:FF:FF:FF:01,32:32:32:31,3600,1565356073,1,0,0\n",
+        "192.0.2.102,FF:FF:FF:FF:FF:02,32:32:32:32,3600,1565356073,1,0,0\n",
+        "192.0.2.103,FF:FF:FF:FF:FF:03,32:32:32:33,3600,1565356073,1,0,0\n",
+        "192.0.2.104,FF:FF:FF:FF:FF:04,32:32:32:34,3600,1565356073,1,0,0\n",
+        "192.0.2.105,FF:FF:FF:FF:FF:05,32:32:32:35,3600,1565356073,1,0,0\n",
+        "192.0.2.106,FF:FF:FF:FF:FF:06,32:32:32:36,3600,1565356073,1,0,0\n",
+        "192.0.2.107,FF:FF:FF:FF:FF:07,32:32:32:37,3600,1565356073,1,0,0\n",
+        "192.0.2.108,08:00:27:25:d3:f4,32:32:32:32,3600,1565356073,1,0,0,,0,\n"
+    };
+
+    std::ostringstream os;
+    os << v4_hdr_;
+    for (auto row : rows) {
+        os << row;
+    }
+
+    io_.writeFile(os.str());
+
+    boost::scoped_ptr<CSVLeaseFile4> lf(new CSVLeaseFile4(filename_));
+    ASSERT_NO_THROW(lf->open());
+
+    // Let's limit the number of errors to 5 (we have 7 in the data) and
+    // try to load the leases.
+    uint32_t max_errors = 5;
+    Lease4Storage storage;
+    ASSERT_THROW(LeaseFileLoader::load<Lease4>(*lf, storage, max_errors), util::CSVFileError);
+
+    // We should have made 7 reads, with 1 lease read, and 6 errors.
+    {
+        SCOPED_TRACE("Failed load stats");
+        checkStats(*lf, 7, 1, 6, 0, 0, 0);
+    }
+
+    // Now let's disable the error limit and try again.
+    max_errors = 0;
+
+    // Load leases from the file. Note, we have to reopen the file.
+    ASSERT_NO_THROW(lf->open());
+    ASSERT_NO_THROW(LeaseFileLoader::load<Lease4>(*lf, storage, max_errors));
+
+    // We should have made 10 reads, with 2 leases read, and 7 errors.
+    {
+        SCOPED_TRACE("Good load stats");
+        checkStats(*lf, 10, 2, 7, 0, 0, 0);
+    }
+}
+
 // This test verifies that the DHCPv6 leases can be loaded from the lease
 // file and that only the most recent entry for each lease is loaded and
 // the previous entries are discarded.
@@ -592,72 +649,58 @@ TEST_F(LeaseFileLoaderTest, loadWrite6LeaseRemove) {
     }
 }
 
-// This test verifies that the exception is thrown when the specific
-// number of errors in the test data occur during reading of the lease
-// file.
-TEST_F(LeaseFileLoaderTest, loadMaxErrors) {
-    std::string test_str;
-    std::string a_1 = "192.0.2.1,06:07:08:09:0a:bc,,"
-                      "200,200,8,1,1,host.example.com,1,\n";
-    std::string a_2 = "192.0.2.1,06:07:08:09:0a:bc,,"
-                      "200,500,8,1,1,host.example.com,1,\n";
+// This test verifies that max-row-errors works correctly for
+// DHCPv6 lease files
+TEST_F(LeaseFileLoaderTest, maxRowErrors6) {
+    // We have 9 rows: 2 that are good, 7 that are flawed (too few fields).
+    std::vector<std::string> rows = {
+        "3002::01,00:03:00:01:08:00:27:25:d3:01,30,1565361388,2,20,0,"
+        "11189196,128,0,0,,08:00:27:25:d3:f4,0,\n",
+        "3002::02,00:03:00:01:08:00:27:25:d3:02,30,1565361388,2,20,0\n",
+        "3002::03,00:03:00:01:08:00:27:25:d3:03,30,1565361388,2,20,0\n",
+        "3002::04,00:03:00:01:08:00:27:25:d3:04,30,1565361388,2,20,0\n",
+        "3002::05,00:03:00:01:08:00:27:25:d3:05,30,1565361388,2,20,0\n",
+        "3002::06,00:03:00:01:08:00:27:25:d3:06,30,1565361388,2,20,0\n",
+        "3002::07,00:03:00:01:08:00:27:25:d3:07,30,1565361388,2,20,0\n",
+        "3002::08,00:03:00:01:08:00:27:25:d3:08,30,1565361388,2,20,0\n",
+        "3002::09,00:03:00:01:08:00:27:25:d3:09,30,1565361388,2,20,0,"
+        "11189196,128,0,0,,08:00:27:25:d3:f4,0,\n"
+    };
 
-    std::string b_1 = "192.0.2.3,,a:11:01:04,200,200,8,1,1,host.example.com,"
-                      "0,\n";
-
-    std::string c_1 = "192.0.2.10,01:02:03:04:05:06,,200,300,8,1,1,,1,\n";
-
-    // Create a lease file for which there is a number of invalid
-    // entries.  b_1 is invalid and gets used multiple times.
-    test_str = v4_hdr_ + a_1 + b_1 + b_1 + c_1 + b_1 + b_1 + a_2;
-    io_.writeFile(test_str);
-
-    boost::scoped_ptr<CSVLeaseFile4> lf(new CSVLeaseFile4(filename_));
-    ASSERT_NO_THROW(lf->open());
-
-    // Load leases and set the maximum number of errors to 3. This
-    // should result in an exception because there are 4 invalid entries.
-    Lease4Storage storage;
-    ASSERT_THROW(LeaseFileLoader::load<Lease4>(*lf, storage, 3),
-                 util::CSVFileError);
-
-    // We should have made 6 attempts to read, with 2 leases read and 4 error
-    {
-    SCOPED_TRACE("Read leases 1");
-    checkStats(*lf, 6, 2, 4, 0, 0, 0);
+    std::ostringstream os;
+    os << v6_hdr_;
+    for (auto row : rows) {
+        os << row;
     }
 
-    lf->close();
+    io_.writeFile(os.str());
+
+    boost::scoped_ptr<CSVLeaseFile6> lf(new CSVLeaseFile6(filename_));
     ASSERT_NO_THROW(lf->open());
 
-    // Repeat the test, but this time allow for 4 invalid entries. It
-    // should load just fine.
-    storage.clear();
-    ASSERT_NO_THROW(LeaseFileLoader::load<Lease4>(*lf, storage, 4));
+    // Let's limit the number of errors to 5 (we have 7 in the data) and
+    // try to load the leases.
+    uint32_t max_errors = 5;
+    Lease6Storage storage;
+    ASSERT_THROW(LeaseFileLoader::load<Lease6>(*lf, storage, max_errors), util::CSVFileError);
 
-    // We should have made 8 attempts to read, with 3 leases read and 4 error
+    // We should have made 7 reads, with 1 lease read, and 6 errors.
     {
-    SCOPED_TRACE("Read leases 2");
-    checkStats(*lf, 8, 3, 4, 0, 0, 0);
+        SCOPED_TRACE("Failed load stats");
+        checkStats(*lf, 7, 1, 6, 0, 0, 0);
     }
 
-    ASSERT_EQ(2, storage.size());
+    // Now let's disable the error limit and try again.
+    max_errors = 0;
 
-    Lease4Ptr lease = getLease<Lease4Ptr>("192.0.2.1", storage);
-    ASSERT_TRUE(lease);
-    EXPECT_EQ(300, lease->cltt_);
+    // Load leases from the file. Note, we have to reopen the file.
+    ASSERT_NO_THROW(lf->open());
+    ASSERT_NO_THROW(LeaseFileLoader::load<Lease6>(*lf, storage, max_errors));
 
-    lease = getLease<Lease4Ptr>("192.0.2.10", storage);
-    ASSERT_TRUE(lease);
-    EXPECT_EQ(100, lease->cltt_);
-
-    test_str = v4_hdr_ + a_2 + c_1;
-    writeLeases<Lease4, CSVLeaseFile4, Lease4Storage>(*lf, storage, test_str);
-
-    // We should have made 1 attempts to write, with 1 leases written and 0 errors
+    // We should have made 10 reads, with 2 leases read, and 7 errors.
     {
-    SCOPED_TRACE("Write leases");
-    checkStats(*lf, 0, 0, 0, 2, 2, 0);
+        SCOPED_TRACE("Good load stats");
+        checkStats(*lf, 10, 2, 7, 0, 0, 0);
     }
 }
 
@@ -820,4 +863,18 @@ TEST_F(LeaseFileLoaderTest, sanityChecker6Del) {
     sanityChecks6("2001::1", 1, "2001::/16", 2, CfgConsistency::LEASE_CHECK_DEL, false, 1);
 }
 
+// This test checks to make sure PD leases are not sanity checked,
+// and thus not discarded.
+TEST_F(LeaseFileLoaderTest, sanityChecker6PD) {
+    int prefix_len = 64;
+
+    // We check a prefix lease whose subnet-id does not exist and
+    // is clearly outside the only known subnet.
+    sanityChecks6("2001:1::", 2,   // create prefix lease in subnet 2
+                  "3001::/64", 1,  // create subnet 1
+                  CfgConsistency::LEASE_CHECK_DEL,
+                  true, 2,         // lease should still exist with subnet id of 2
+                  prefix_len);
+}
+
 } // end of anonymous namespace
