@@ -18,6 +18,7 @@
 #include <pgsql/pgsql_connection.h>
 #include <pgsql/testutils/pgsql_schema.h>
 #include <util/multi_threading_mgr.h>
+#include <testutils/multi_threading_utils.h>
 
 #include <gtest/gtest.h>
 
@@ -34,6 +35,7 @@ using namespace isc::db::test;
 using namespace isc::dhcp;
 using namespace isc::dhcp::test;
 using namespace isc::data;
+using namespace isc::test;
 using namespace isc::util;
 using namespace std;
 
@@ -240,7 +242,7 @@ TEST(PgSqlHostDataSource, OpenDatabase) {
 /// opened: the fixtures assume that and check basic operations.
 TEST(PgSqlHostDataSource, OpenDatabaseMultiThreading) {
     // Enable Multi-Threading.
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
 
     // Schema needs to be created for the test to work.
     destroyPgSQLSchema();
@@ -359,7 +361,7 @@ TEST(PgSqlHostDataSource, NoCallbackOnOpenFail) {
 /// as a system test.
 TEST(PgSqlHostDataSource, NoCallbackOnOpenFailMultiThreading) {
     // Enable Multi-Threading.
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
 
     // Schema needs to be created for the test to work.
     destroyPgSQLSchema();
@@ -383,7 +385,7 @@ TEST_F(PgSqlHostDataSourceTest, testReadOnlyDatabase) {
 
 /// @brief This test verifies that database backend can operate in Read-Only mode.
 TEST_F(PgSqlHostDataSourceTest, testReadOnlyDatabaseMultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testReadOnlyDatabase(PGSQL_VALID_TYPE);
 }
 
@@ -396,7 +398,7 @@ TEST_F(PgSqlHostDataSourceTest, basic4HWAddr) {
 /// @brief Test verifies if a host reservation can be added and later retrieved by IPv4
 /// address. Host uses hw address as identifier.
 TEST_F(PgSqlHostDataSourceTest, basic4HWAddrMultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testBasic4(Host::IDENT_HWADDR);
 }
 
@@ -409,7 +411,7 @@ TEST_F(PgSqlHostDataSourceTest, globalSubnetId4) {
 /// @brief Verifies that IPv4 host reservation with options can have a the global
 /// subnet id value
 TEST_F(PgSqlHostDataSourceTest, globalSubnetId4MultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testGlobalSubnetId4();
 }
 
@@ -422,7 +424,7 @@ TEST_F(PgSqlHostDataSourceTest, globalSubnetId6) {
 /// @brief Verifies that IPv6 host reservation with options can have a the global
 /// subnet id value
 TEST_F(PgSqlHostDataSourceTest, globalSubnetId6MultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testGlobalSubnetId6();
 }
 
@@ -435,7 +437,7 @@ TEST_F(PgSqlHostDataSourceTest, maxSubnetId4) {
 /// @brief Verifies that IPv4 host reservation with options can have a max value
 /// for  dhcp4_subnet id
 TEST_F(PgSqlHostDataSourceTest, maxSubnetId4MultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testMaxSubnetId4();
 }
 
@@ -448,7 +450,7 @@ TEST_F(PgSqlHostDataSourceTest, maxSubnetId6) {
 /// @brief Verifies that IPv6 host reservation with options can have a max value
 /// for  dhcp6_subnet id
 TEST_F(PgSqlHostDataSourceTest, maxSubnetId6MultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testMaxSubnetId6();
 }
 
@@ -459,7 +461,7 @@ TEST_F(PgSqlHostDataSourceTest, getAll4BySubnet) {
 
 /// @brief Verifies that IPv4 host reservations in the same subnet can be retrieved
 TEST_F(PgSqlHostDataSourceTest, getAll4BySubnetMultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testGetAll4();
 }
 
@@ -470,7 +472,7 @@ TEST_F(PgSqlHostDataSourceTest, getAll6BySubnet) {
 
 /// @brief Verifies that IPv6 host reservations in the same subnet can be retrieved
 TEST_F(PgSqlHostDataSourceTest, getAll6BySubnetMultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testGetAll6();
 }
 
@@ -481,7 +483,7 @@ TEST_F(PgSqlHostDataSourceTest, getAllbyHostname) {
 
 /// @brief Verifies that host reservations with the same hostname can be retrieved
 TEST_F(PgSqlHostDataSourceTest, getAllbyHostnameMultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testGetAllbyHostname();
 }
 
@@ -494,7 +496,7 @@ TEST_F(PgSqlHostDataSourceTest, getAllbyHostnameSubnet4) {
 /// @brief Verifies that IPv4 host reservations with the same hostname and in
 /// the same subnet can be retrieved
 TEST_F(PgSqlHostDataSourceTest, getAllbyHostnameSubnet4MultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testGetAllbyHostnameSubnet4();
 }
 
@@ -507,7 +509,7 @@ TEST_F(PgSqlHostDataSourceTest, getAllbyHostnameSubnet6) {
 /// @brief Verifies that IPv6 host reservations with the same hostname and in
 /// the same subnet can be retrieved
 TEST_F(PgSqlHostDataSourceTest, getAllbyHostnameSubnet6MultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testGetAllbyHostnameSubnet6();
 }
 
@@ -520,7 +522,7 @@ TEST_F(PgSqlHostDataSourceTest, getPage4) {
 /// @brief Verifies that IPv4 host reservations in the same subnet can be retrieved
 /// by pages.
 TEST_F(PgSqlHostDataSourceTest, getPage4MultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testGetPage4();
 }
 
@@ -533,7 +535,7 @@ TEST_F(PgSqlHostDataSourceTest, getPage6) {
 /// @brief Verifies that IPv6 host reservations in the same subnet can be retrieved
 /// by pages.
 TEST_F(PgSqlHostDataSourceTest, getPage6MultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testGetPage6();
 }
 
@@ -546,7 +548,7 @@ TEST_F(PgSqlHostDataSourceTest, getPageLimit4) {
 /// @brief Verifies that IPv4 host reservations in the same subnet can be retrieved
 /// by pages without truncation from the limit.
 TEST_F(PgSqlHostDataSourceTest, getPageLimit4MultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testGetPageLimit4(Host::IDENT_DUID);
 }
 
@@ -559,7 +561,7 @@ TEST_F(PgSqlHostDataSourceTest, getPageLimit6) {
 /// @brief Verifies that IPv6 host reservations in the same subnet can be retrieved
 /// by pages without truncation from the limit.
 TEST_F(PgSqlHostDataSourceTest, getPageLimit6MultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testGetPageLimit6(Host::IDENT_HWADDR);
 }
 
@@ -572,7 +574,7 @@ TEST_F(PgSqlHostDataSourceTest, getPage4Subnets) {
 /// @brief Verifies that IPv4 host reservations in the same subnet can be retrieved
 /// by pages even with multiple subnets.
 TEST_F(PgSqlHostDataSourceTest, getPage4SubnetsMultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testGetPage4Subnets();
 }
 
@@ -585,7 +587,7 @@ TEST_F(PgSqlHostDataSourceTest, getPage6Subnets) {
 /// @brief Verifies that IPv6 host reservations in the same subnet can be retrieved
 /// by pages even with multiple subnets.
 TEST_F(PgSqlHostDataSourceTest, getPage6SubnetsMultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testGetPage6Subnets();
 }
 
@@ -598,7 +600,7 @@ TEST_F(PgSqlHostDataSourceTest, basic4ClientId) {
 /// @brief Test verifies if a host reservation can be added and later retrieved by IPv4
 /// address. Host uses client-id (DUID) as identifier.
 TEST_F(PgSqlHostDataSourceTest, basic4ClientIdMultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testBasic4(Host::IDENT_DUID);
 }
 
@@ -611,7 +613,7 @@ TEST_F(PgSqlHostDataSourceTest, getByIPv4HWaddr) {
 /// @brief Test verifies that multiple hosts can be added and later retrieved by their
 /// reserved IPv4 address. This test uses HW addresses as identifiers.
 TEST_F(PgSqlHostDataSourceTest, getByIPv4HWaddrMultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testGetByIPv4(Host::IDENT_HWADDR);
 }
 
@@ -624,7 +626,7 @@ TEST_F(PgSqlHostDataSourceTest, getByIPv4ClientId) {
 /// @brief Test verifies that multiple hosts can be added and later retrieved by their
 /// reserved IPv4 address. This test uses client-id (DUID) as identifiers.
 TEST_F(PgSqlHostDataSourceTest, getByIPv4ClientIdMultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testGetByIPv4(Host::IDENT_DUID);
 }
 
@@ -637,7 +639,7 @@ TEST_F(PgSqlHostDataSourceTest, get4ByHWaddr) {
 /// @brief Test verifies if a host reservation can be added and later retrieved by
 /// hardware address.
 TEST_F(PgSqlHostDataSourceTest, get4ByHWaddrMultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testGet4ByIdentifier(Host::IDENT_HWADDR);
 }
 
@@ -650,7 +652,7 @@ TEST_F(PgSqlHostDataSourceTest, get4ByDUID) {
 /// @brief Test verifies if a host reservation can be added and later retrieved by
 /// DUID.
 TEST_F(PgSqlHostDataSourceTest, get4ByDUIDMultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testGet4ByIdentifier(Host::IDENT_DUID);
 }
 
@@ -663,7 +665,7 @@ TEST_F(PgSqlHostDataSourceTest, get4ByCircuitId) {
 /// @brief Test verifies if a host reservation can be added and later retrieved by
 /// circuit id.
 TEST_F(PgSqlHostDataSourceTest, get4ByCircuitIdMultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testGet4ByIdentifier(Host::IDENT_CIRCUIT_ID);
 }
 
@@ -676,7 +678,7 @@ TEST_F(PgSqlHostDataSourceTest, get4ByClientId) {
 /// @brief Test verifies if a host reservation can be added and later retrieved by
 /// client-id.
 TEST_F(PgSqlHostDataSourceTest, get4ByClientIdMultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testGet4ByIdentifier(Host::IDENT_CLIENT_ID);
 }
 
@@ -687,7 +689,7 @@ TEST_F(PgSqlHostDataSourceTest, hwaddrNotClientId1) {
 
 /// @brief Test verifies if hardware address and client identifier are not confused.
 TEST_F(PgSqlHostDataSourceTest, hwaddrNotClientId1MultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testHWAddrNotClientId();
 }
 
@@ -698,7 +700,7 @@ TEST_F(PgSqlHostDataSourceTest, hwaddrNotClientId2) {
 
 /// @brief Test verifies if hardware address and client identifier are not confused.
 TEST_F(PgSqlHostDataSourceTest, hwaddrNotClientId2MultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testClientIdNotHWAddr();
 }
 
@@ -709,7 +711,7 @@ TEST_F(PgSqlHostDataSourceTest, hostnameFQDN) {
 
 /// @brief Test verifies if a host with FQDN hostname can be stored and later retrieved.
 TEST_F(PgSqlHostDataSourceTest, hostnameFQDNMultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testHostname("foo.example.org", 1);
 }
 
@@ -722,7 +724,7 @@ TEST_F(PgSqlHostDataSourceTest, hostnameFQDN100) {
 /// @brief Test verifies if 100 hosts with unique FQDN hostnames can be stored and later
 /// retrieved.
 TEST_F(PgSqlHostDataSourceTest, hostnameFQDN100MultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testHostname("foo.example.org", 100);
 }
 
@@ -735,7 +737,7 @@ TEST_F(PgSqlHostDataSourceTest, noHostname) {
 /// @brief Test verifies if a host without any hostname specified can be stored and later
 /// retrieved.
 TEST_F(PgSqlHostDataSourceTest, noHostnameMultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testHostname("", 1);
 }
 
@@ -747,7 +749,7 @@ TEST_F(PgSqlHostDataSourceTest, usercontext) {
 
 /// @brief Test verifies if a host with user context can be stored and later retrieved.
 TEST_F(PgSqlHostDataSourceTest, usercontextMultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     string comment = "{ \"comment\": \"a host reservation\" }";
     testUserContext(Element::fromJSON(comment));
 }
@@ -764,7 +766,7 @@ TEST_F(PgSqlHostDataSourceTest, DISABLED_hwaddrOrClientId1) {
 
 /// @brief Test verifies if the hardware or client-id query can match hardware address.
 TEST_F(PgSqlHostDataSourceTest, DISABLED_hwaddrOrClientId1MultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     /// @todo: The logic behind ::get4(subnet_id, hwaddr, duid) call needs to
     /// be discussed.
     ///
@@ -785,7 +787,7 @@ TEST_F(PgSqlHostDataSourceTest, DISABLED_hwaddrOrClientId2) {
 
 /// @brief Test verifies if the hardware or client-id query can match client-id.
 TEST_F(PgSqlHostDataSourceTest, DISABLED_hwaddrOrClientId2MultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     /// @todo: The logic behind ::get4(subnet_id, hwaddr, duid) call needs to
     /// be discussed.
     ///
@@ -803,7 +805,7 @@ TEST_F(PgSqlHostDataSourceTest, get6AddrWithDuid) {
 /// @brief Test verifies that host with IPv6 address and DUID can be added and
 /// later retrieved by IPv6 address.
 TEST_F(PgSqlHostDataSourceTest, get6AddrWithDuidMultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testGetByIPv6(Host::IDENT_DUID, false);
 }
 
@@ -816,7 +818,7 @@ TEST_F(PgSqlHostDataSourceTest, get6AddrWithHWAddr) {
 /// @brief Test verifies that host with IPv6 address and HWAddr can be added and
 /// later retrieved by IPv6 address.
 TEST_F(PgSqlHostDataSourceTest, get6AddrWithHWAddrMultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testGetByIPv6(Host::IDENT_HWADDR, false);
 }
 
@@ -829,7 +831,7 @@ TEST_F(PgSqlHostDataSourceTest, get6PrefixWithDuid) {
 /// @brief Test verifies that host with IPv6 prefix and DUID can be added and
 /// later retrieved by IPv6 prefix.
 TEST_F(PgSqlHostDataSourceTest, get6PrefixWithDuidMultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testGetByIPv6(Host::IDENT_DUID, true);
 }
 
@@ -842,7 +844,7 @@ TEST_F(PgSqlHostDataSourceTest, get6PrefixWithHWaddr) {
 /// @brief Test verifies that host with IPv6 prefix and HWAddr can be added and
 /// later retrieved by IPv6 prefix.
 TEST_F(PgSqlHostDataSourceTest, get6PrefixWithHWaddrMultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testGetByIPv6(Host::IDENT_HWADDR, true);
 }
 
@@ -855,7 +857,7 @@ TEST_F(PgSqlHostDataSourceTest, get6SubnetPrefix) {
 /// @brief Test verifies that host with IPv6 prefix reservation can be retrieved
 /// by subnet id and prefix value.
 TEST_F(PgSqlHostDataSourceTest, get6SubnetPrefixMultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testGetBySubnetIPv6();
 }
 
@@ -868,7 +870,7 @@ TEST_F(PgSqlHostDataSourceTest, get6ByHWaddr) {
 /// @brief Test verifies if a host reservation can be added and later retrieved by
 /// hardware address.
 TEST_F(PgSqlHostDataSourceTest, get6ByHWaddrMultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testGet6ByHWAddr();
 }
 
@@ -881,7 +883,7 @@ TEST_F(PgSqlHostDataSourceTest, get6ByClientId) {
 /// @brief Test verifies if a host reservation can be added and later retrieved by
 /// client identifier.
 TEST_F(PgSqlHostDataSourceTest, get6ByClientIdMultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testGet6ByClientId();
 }
 
@@ -894,7 +896,7 @@ TEST_F(PgSqlHostDataSourceTest, addr6AndPrefix) {
 /// @brief Test verifies if a host reservation can be stored with both IPv6 address and
 /// prefix.
 TEST_F(PgSqlHostDataSourceTest, addr6AndPrefixMultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testAddr6AndPrefix();
 }
 
@@ -907,7 +909,7 @@ TEST_F(PgSqlHostDataSourceTest, multipleReservations) {
 /// @brief Tests if host with multiple IPv6 reservations can be added and then
 /// retrieved correctly. Test checks reservations comparing.
 TEST_F(PgSqlHostDataSourceTest, multipleReservationsMultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testMultipleReservations();
 }
 
@@ -920,7 +922,7 @@ TEST_F(PgSqlHostDataSourceTest, multipleReservationsDifferentOrder) {
 /// @brief Tests if compareIPv6Reservations() method treats same pool of reservations
 /// but added in different order as equal.
 TEST_F(PgSqlHostDataSourceTest, multipleReservationsDifferentOrderMultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testMultipleReservationsDifferentOrder();
 }
 
@@ -933,7 +935,7 @@ TEST_F(PgSqlHostDataSourceTest, multipleClientClasses4) {
 /// @brief Test that multiple client classes for IPv4 can be inserted and
 /// retrieved for a given host reservation.
 TEST_F(PgSqlHostDataSourceTest, multipleClientClasses4MultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testMultipleClientClasses4();
 }
 
@@ -946,7 +948,7 @@ TEST_F(PgSqlHostDataSourceTest, multipleClientClasses6) {
 /// @brief Test that multiple client classes for IPv6 can be inserted and
 /// retrieved for a given host reservation.
 TEST_F(PgSqlHostDataSourceTest, multipleClientClasses6MultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testMultipleClientClasses6();
 }
 
@@ -959,7 +961,7 @@ TEST_F(PgSqlHostDataSourceTest, multipleClientClassesBoth) {
 /// @brief Test that multiple client classes for both IPv4 and IPv6 can
 /// be inserted and retrieved for a given host reservation.
 TEST_F(PgSqlHostDataSourceTest, multipleClientClassesBothMultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testMultipleClientClassesBoth();
 }
 
@@ -978,7 +980,7 @@ TEST_F(PgSqlHostDataSourceTest, multipleSubnetsHWAddr) {
 /// hardware address), but for different subnets (different subnet-ids).
 /// Make sure that getAll() returns them all correctly.
 TEST_F(PgSqlHostDataSourceTest, multipleSubnetsHWAddrMultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testMultipleSubnets(10, Host::IDENT_HWADDR);
 }
 
@@ -999,7 +1001,7 @@ TEST_F(PgSqlHostDataSourceTest, multipleSubnetsClientId) {
 /// client-identifier), but for different subnets (different subnet-ids).
 /// Make sure that getAll() returns them correctly.
 TEST_F(PgSqlHostDataSourceTest, multipleSubnetsClientIdMultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testMultipleSubnets(10, Host::IDENT_DUID);
 }
 
@@ -1018,7 +1020,7 @@ TEST_F(PgSqlHostDataSourceTest, subnetId6) {
 /// Insert 10 host reservations for different subnets. Make sure that
 /// get6(subnet-id, ...) calls return correct reservation.
 TEST_F(PgSqlHostDataSourceTest, subnetId6MultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testSubnetId6(10, Host::IDENT_HWADDR);
 }
 
@@ -1035,7 +1037,7 @@ TEST_F(PgSqlHostDataSourceTest, addDuplicate6WithDUID) {
 /// verify that the second and following attempts will throw exceptions.
 /// Hosts with same DUID.
 TEST_F(PgSqlHostDataSourceTest, addDuplicate6WithDUIDMultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testAddDuplicate6WithSameDUID();
 }
 
@@ -1052,7 +1054,7 @@ TEST_F(PgSqlHostDataSourceTest, addDuplicate6WithHWAddr) {
 /// verify that the second and following attempts will throw exceptions.
 /// Hosts with same HWAddr.
 TEST_F(PgSqlHostDataSourceTest, addDuplicate6WithHWAddrMultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testAddDuplicate6WithSameHWAddr();
 }
 
@@ -1067,7 +1069,7 @@ TEST_F(PgSqlHostDataSourceTest, addDuplicate4) {
 /// follows: try to add multiple instances of the same host reservation and
 /// verify that the second and following attempts will throw exceptions.
 TEST_F(PgSqlHostDataSourceTest, addDuplicate4MultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testAddDuplicate4();
 }
 
@@ -1081,7 +1083,7 @@ TEST_F(PgSqlHostDataSourceTest, optionsReservations4) {
 /// @brief This test verifies that DHCPv4 options can be inserted in a binary format
 /// and retrieved from the PostgreSQL host database.
 TEST_F(PgSqlHostDataSourceTest, optionsReservations4MultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     string comment = "{ \"comment\": \"a host reservation\" }";
     testOptionsReservations4(false, Element::fromJSON(comment));
 }
@@ -1096,7 +1098,7 @@ TEST_F(PgSqlHostDataSourceTest, optionsReservations6) {
 /// @brief This test verifies that DHCPv6 options can be inserted in a binary format
 /// and retrieved from the PostgreSQL host database.
 TEST_F(PgSqlHostDataSourceTest, optionsReservations6MultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     string comment = "{ \"comment\": \"a host reservation\" }";
     testOptionsReservations6(false, Element::fromJSON(comment));
 }
@@ -1110,7 +1112,7 @@ TEST_F(PgSqlHostDataSourceTest, optionsReservations46) {
 /// @brief This test verifies that DHCPv4 and DHCPv6 options can be inserted in a
 /// binary format and retrieved with a single query to the database.
 TEST_F(PgSqlHostDataSourceTest, optionsReservations46MultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testOptionsReservations46(false);
 }
 
@@ -1124,7 +1126,7 @@ TEST_F(PgSqlHostDataSourceTest, formattedOptionsReservations4) {
 /// @brief This test verifies that DHCPv4 options can be inserted in a textual format
 /// and retrieved from the PostgreSQL host database.
 TEST_F(PgSqlHostDataSourceTest, formattedOptionsReservations4MultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     string comment = "{ \"comment\": \"a host reservation\" }";
     testOptionsReservations4(true, Element::fromJSON(comment));
 }
@@ -1139,7 +1141,7 @@ TEST_F(PgSqlHostDataSourceTest, formattedOptionsReservations6) {
 /// @brief This test verifies that DHCPv6 options can be inserted in a textual format
 /// and retrieved from the PostgreSQL host database.
 TEST_F(PgSqlHostDataSourceTest, formattedOptionsReservations6MultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     string comment = "{ \"comment\": \"a host reservation\" }";
     testOptionsReservations6(true, Element::fromJSON(comment));
 }
@@ -1153,7 +1155,7 @@ TEST_F(PgSqlHostDataSourceTest, formattedOptionsReservations46) {
 /// @brief This test verifies that DHCPv4 and DHCPv6 options can be inserted in a
 /// textual format and retrieved with a single query to the database.
 TEST_F(PgSqlHostDataSourceTest, formattedOptionsReservations46MultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testOptionsReservations46(true);
 }
 
@@ -1210,7 +1212,7 @@ TEST_F(PgSqlHostDataSourceTest, testAddRollback) {
 /// into the database. The failure to insert host information at
 /// any stage should cause the whole transaction to be rolled back.
 TEST_F(PgSqlHostDataSourceTest, testAddRollbackMultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     // Make sure we have the pointer to the host data source.
     ASSERT_TRUE(hdsptr_);
 
@@ -1265,7 +1267,7 @@ TEST_F(PgSqlHostDataSourceTest, messageFields) {
 /// @brief This test checks that siaddr, sname, file fields can be retrieved
 /// from a database for a host.
 TEST_F(PgSqlHostDataSourceTest, messageFieldsMultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testMessageFields4();
 }
 
@@ -1276,7 +1278,7 @@ TEST_F(PgSqlHostDataSourceTest, deleteByAddr4) {
 
 /// @brief Check that delete(subnet-id, addr4) works.
 TEST_F(PgSqlHostDataSourceTest, deleteByAddr4MultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testDeleteByAddr4();
 }
 
@@ -1287,7 +1289,7 @@ TEST_F(PgSqlHostDataSourceTest, deleteById4) {
 
 /// @brief Check that delete(subnet4-id, identifier-type, identifier) works.
 TEST_F(PgSqlHostDataSourceTest, deleteById4MultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testDeleteById4();
 }
 
@@ -1300,7 +1302,7 @@ TEST_F(PgSqlHostDataSourceTest, deleteById4Options) {
 /// @brief Check that delete(subnet4-id, identifier-type, identifier) works,
 /// even when options are present.
 TEST_F(PgSqlHostDataSourceTest, deleteById4OptionsMultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testDeleteById4Options();
 }
 
@@ -1311,7 +1313,7 @@ TEST_F(PgSqlHostDataSourceTest, deleteById6) {
 
 /// @brief Check that delete(subnet6-id, identifier-type, identifier) works.
 TEST_F(PgSqlHostDataSourceTest, deleteById6MultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testDeleteById6();
 }
 
@@ -1324,7 +1326,7 @@ TEST_F(PgSqlHostDataSourceTest, deleteById6Options) {
 /// @brief Check that delete(subnet6-id, identifier-type, identifier) works,
 /// even when options are present.
 TEST_F(PgSqlHostDataSourceTest, deleteById6OptionsMultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testDeleteById6Options();
 }
 
@@ -1337,7 +1339,7 @@ TEST_F(PgSqlHostDataSourceTest, testMultipleHostsNoAddress4) {
 /// @brief Tests that multiple reservations without IPv4 addresses can be
 /// specified within a subnet.
 TEST_F(PgSqlHostDataSourceTest, testMultipleHostsNoAddress4MultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testMultipleHostsNoAddress4();
 }
 
@@ -1348,7 +1350,7 @@ TEST_F(PgSqlHostDataSourceTest, testMultipleHosts6) {
 
 /// @brief Tests that multiple hosts can be specified within an IPv6 subnet.
 TEST_F(PgSqlHostDataSourceTest, testMultipleHosts6MultiThreading) {
-    MultiThreadingMgr::instance().setMode(true);
+    MultiThreadingTest mt(true);
     testMultipleHosts6();
 }
 
