@@ -8,9 +8,8 @@
 
 #include <stats/observation.h>
 #include <exceptions/exceptions.h>
-#include <util/boost_time_utils.h>
+#include <util/chrono_time_utils.h>
 #include <boost/shared_ptr.hpp>
-#include <boost/date_time/posix_time/posix_time_types.hpp>
 #include <gtest/gtest.h>
 
 #include <iostream>
@@ -20,10 +19,25 @@
 
 using namespace isc;
 using namespace isc::stats;
-using namespace boost::posix_time;
+using namespace std::chrono;
 
 namespace {
 
+static const StatsDuration& dur1234(hours(1) + minutes(2) + seconds(3) +
+                                    milliseconds(4));
+static const StatsDuration& dur5678(hours(5) + minutes(6) + seconds(7) +
+                                    milliseconds(8));
+static const StatsDuration& dur681012(hours(6) + minutes(8) + seconds(10) +
+                                      milliseconds(12));
+static const StatsDuration& dur453(minutes(4) + seconds(5) + milliseconds(3));
+
+// This test verifies that the number of seconds can be retrieved.
+TEST(StatsDurationTest, toSeconds) {
+    StatsDuration dur = StatsDuration::zero();
+    dur += hours(1) + minutes(1) + seconds(1) + milliseconds(1);
+    EXPECT_EQ(3661, toSeconds(dur));
+}
+
 /// @brief Test class for Observation
 ///
 /// This simple fixture class initializes four observations:
@@ -36,7 +50,7 @@ public:
     ObservationTest() :
         a("alpha", static_cast<int64_t>(1234)), // integer
         b("beta", 12.34), // float
-        c("gamma", millisec::time_duration(1, 2, 3, 4)), // duration
+        c("gamma", dur1234), // duration
         d("delta", "1234") { // string
     }
 
@@ -56,8 +70,7 @@ TEST_F(ObservationTest, constructor) {
 
     EXPECT_EQ(1234, a.getInteger().first);
     EXPECT_EQ(12.34, b.getFloat().first);
-    EXPECT_EQ(millisec::time_duration(1, 2, 3, 4),
-              c.getDuration().first);
+    EXPECT_EQ(dur1234, c.getDuration().first);
     EXPECT_EQ("1234", d.getString().first);
 
     // Let's check that attempting to get a different type
@@ -84,23 +97,23 @@ TEST_F(ObservationTest, constructor) {
 TEST_F(ObservationTest, setValue) {
     EXPECT_NO_THROW(a.setValue(static_cast<int64_t>(5678)));
     EXPECT_NO_THROW(b.setValue(56e+78));
-    EXPECT_NO_THROW(c.setValue(millisec::time_duration(5, 6, 7, 8)));
+    EXPECT_NO_THROW(c.setValue(dur5678));
     EXPECT_NO_THROW(d.setValue("fiveSixSevenEight"));
 
 
     EXPECT_EQ(5678, a.getInteger().first);
     EXPECT_EQ(56e+78, b.getFloat().first);
-    EXPECT_EQ(millisec::time_duration(5, 6, 7, 8), c.getDuration().first);
+    EXPECT_EQ(dur5678, c.getDuration().first);
     EXPECT_EQ("fiveSixSevenEight", d.getString().first);
 
     // Now check whether setting value to a different type does
     // throw an exception
     EXPECT_THROW(a.setValue(56e+78), InvalidStatType);
-    EXPECT_THROW(a.setValue(millisec::time_duration(5, 6, 7, 8)), InvalidStatType);
+    EXPECT_THROW(a.setValue(dur5678), InvalidStatType);
     EXPECT_THROW(a.setValue("fiveSixSevenEight"), InvalidStatType);
 
     EXPECT_THROW(b.setValue(static_cast<int64_t>(5678)), InvalidStatType);
-    EXPECT_THROW(b.setValue(millisec::time_duration(5, 6, 7, 8)), InvalidStatType);
+    EXPECT_THROW(b.setValue(dur5678), InvalidStatType);
     EXPECT_THROW(b.setValue("fiveSixSevenEight"), InvalidStatType);
 
     EXPECT_THROW(c.setValue(static_cast<int64_t>(5678)), InvalidStatType);
@@ -109,7 +122,7 @@ TEST_F(ObservationTest, setValue) {
 
     EXPECT_THROW(d.setValue(static_cast<int64_t>(5678)), InvalidStatType);
     EXPECT_THROW(d.setValue(56e+78), InvalidStatType);
-    EXPECT_THROW(d.setValue(millisec::time_duration(5, 6, 7, 8)), InvalidStatType);
+    EXPECT_THROW(d.setValue(dur5678), InvalidStatType);
 }
 
 // This test checks whether it is possible to add value to existing
@@ -120,12 +133,12 @@ TEST_F(ObservationTest, addValue) {
 
     EXPECT_NO_THROW(a.addValue(static_cast<int64_t>(5678)));
     EXPECT_NO_THROW(b.addValue(56.78));
-    EXPECT_NO_THROW(c.addValue(millisec::time_duration(5, 6, 7, 8)));
+    EXPECT_NO_THROW(c.addValue(dur5678));
     EXPECT_NO_THROW(d.addValue("fiveSixSevenEight"));
 
     EXPECT_EQ(6912, a.getInteger().first);
     EXPECT_EQ(69.12, b.getFloat().first);
-    EXPECT_EQ(millisec::time_duration(6, 8, 10, 12), c.getDuration().first);
+    EXPECT_EQ(dur681012, c.getDuration().first);
     EXPECT_EQ("1234fiveSixSevenEight", d.getString().first);
 
     ASSERT_EQ(a.getSize(), 2);
@@ -140,18 +153,18 @@ TEST_F(ObservationTest, moreThanOne) {
     // Arrays of 4 types of samples
     int64_t int_samples[3] = {1234, 6912, 5678};
     double float_samples[3] = {12.34, 69.12, 56e+78};
-    millisec::time_duration duration_samples[3] = {millisec::time_duration(1, 2, 3, 4),
-        millisec::time_duration(6, 8, 10, 12), millisec::time_duration(5, 6, 7, 8)};
+    StatsDuration duration_samples[3] = {dur1234,
+        dur681012, dur5678};
     std::string string_samples[3] = {"1234", "1234fiveSixSevenEight", "fiveSixSevenEight"};
 
     EXPECT_NO_THROW(a.addValue(static_cast<int64_t>(5678)));
     EXPECT_NO_THROW(b.addValue(56.78));
-    EXPECT_NO_THROW(c.addValue(millisec::time_duration(5, 6, 7, 8)));
+    EXPECT_NO_THROW(c.addValue(dur5678));
     EXPECT_NO_THROW(d.addValue("fiveSixSevenEight"));
 
     EXPECT_NO_THROW(a.setValue(static_cast<int64_t>(5678)));
     EXPECT_NO_THROW(b.setValue(56e+78));
-    EXPECT_NO_THROW(c.setValue(millisec::time_duration(5, 6, 7, 8)));
+    EXPECT_NO_THROW(c.setValue(dur5678));
     EXPECT_NO_THROW(d.setValue("fiveSixSevenEight"));
 
     ASSERT_EQ(a.getSize(), 3);
@@ -203,7 +216,7 @@ TEST_F(ObservationTest, getSize) {
 
     a.addValue(static_cast<int64_t>(5678));
     b.addValue(56.78);
-    c.addValue(millisec::time_duration(5, 6, 7, 8));
+    c.addValue(dur5678);
     d.addValue("fiveSixSevenEight");
 
     EXPECT_NO_THROW(a.getSize());
@@ -219,7 +232,7 @@ TEST_F(ObservationTest, getSize) {
 
     a.setValue(static_cast<int64_t>(5678));
     b.setValue(56e+78);
-    c.setValue(millisec::time_duration(5, 6, 7, 8));
+    c.setValue(dur5678);
     d.setValue("fiveSixSevenEight");
 
     EXPECT_NO_THROW(a.getSize());
@@ -245,10 +258,10 @@ TEST_F(ObservationTest, setCountLimit) {
     std::string string_samples[22] = {"a", "b", "c", "d", "e", "f", "g", "h",
             "i", "j", "k", "l", "m", "n", "o", "p", "q", "r", "s", "t", "u",
             "v"};
-    millisec::time_duration duration_samples[22];
+    StatsDuration duration_samples[22];
 
     for (uint32_t i = 0; i < 22; ++i) {
-        duration_samples[i] = millisec::time_duration(0, 0, 0, i);
+        duration_samples[i] = milliseconds(i);
     }
 
     // By default the max_sample_count is set to 20 and max_sample_age
@@ -355,7 +368,7 @@ TEST_F(ObservationTest, setCountLimit) {
     // Add new values to each type of Observation
     a.setValue(static_cast<int64_t>(21));
     b.setValue(21.0);
-    c.setValue(millisec::time_duration(0, 0, 0, 21));
+    c.setValue(milliseconds(21));
     d.setValue("v");
 
     samples_int = a.getIntegers();
@@ -394,29 +407,29 @@ TEST_F(ObservationTest, setCountLimit) {
 // Checks whether setting age limits works properly
 TEST_F(ObservationTest, setAgeLimit) {
     // Set max_sample_age to 1 second
-    ASSERT_NO_THROW(c.setMaxSampleAge(millisec::time_duration(0, 0, 1, 0)));
+    ASSERT_NO_THROW(c.setMaxSampleAge(seconds(1)));
     // Add some value
-    c.setValue(millisec::time_duration(0, 0, 0, 5));
+    c.setValue(milliseconds(5));
     // Wait 1 second
     sleep(1);
     // and add new value
-    c.setValue(millisec::time_duration(0, 0, 0, 3));
+    c.setValue(milliseconds(3));
 
     // get the list of all samples
     std::list<DurationSample> samples_duration = c.getDurations();
     // check whether the size of samples is equal to 1
     ASSERT_EQ(c.getSize(), 1);
     // and whether it contains an expected value
-    EXPECT_EQ((*samples_duration.begin()).first, millisec::time_duration(0, 0, 0, 3));
+    EXPECT_EQ((*samples_duration.begin()).first, milliseconds(3));
 
     // Wait 1 second to ensure removing previously set value
     sleep(1);
     // add 10 new values
     for (uint32_t i = 0; i < 10; ++i) {
-        c.setValue(millisec::time_duration(0, 0, 0, i));
+        c.setValue(milliseconds(i));
     }
     // change the max_sample_age to smaller
-    ASSERT_NO_THROW(c.setMaxSampleAge(millisec::time_duration(0, 0, 0, 300)));
+    ASSERT_NO_THROW(c.setMaxSampleAge(milliseconds(300)));
 
     samples_duration = c.getDurations();
     // check whether the size of samples is equal to 10
@@ -425,7 +438,7 @@ TEST_F(ObservationTest, setAgeLimit) {
     // and whether it contains expected values
     uint32_t i = 9;
     for (std::list<DurationSample>::iterator it = samples_duration.begin(); it != samples_duration.end(); ++it) {
-        EXPECT_EQ((*it).first, millisec::time_duration(0, 0, 0, i));
+        EXPECT_EQ((*it).first, milliseconds(i));
         --i;
     }
 }
@@ -450,20 +463,20 @@ TEST_F(ObservationTest, getLimits) {
     EXPECT_EQ(d.getMaxSampleCount().second, 20);
 
     // change limit to time duration
-    ASSERT_NO_THROW(a.setMaxSampleAge(millisec::time_duration(0, 4, 5, 3)));
-    ASSERT_NO_THROW(b.setMaxSampleAge(millisec::time_duration(0, 4, 5, 3)));
-    ASSERT_NO_THROW(c.setMaxSampleAge(millisec::time_duration(0, 4, 5, 3)));
-    ASSERT_NO_THROW(d.setMaxSampleAge(millisec::time_duration(0, 4, 5, 3)));
+    ASSERT_NO_THROW(a.setMaxSampleAge(dur453));
+    ASSERT_NO_THROW(b.setMaxSampleAge(dur453));
+    ASSERT_NO_THROW(c.setMaxSampleAge(dur453));
+    ASSERT_NO_THROW(d.setMaxSampleAge(dur453));
 
     EXPECT_EQ(a.getMaxSampleAge().first, true);
     EXPECT_EQ(b.getMaxSampleAge().first, true);
     EXPECT_EQ(c.getMaxSampleAge().first, true);
     EXPECT_EQ(d.getMaxSampleAge().first, true);
 
-    EXPECT_EQ(a.getMaxSampleAge().second, millisec::time_duration(0, 4, 5, 3));
-    EXPECT_EQ(b.getMaxSampleAge().second, millisec::time_duration(0, 4, 5, 3));
-    EXPECT_EQ(c.getMaxSampleAge().second, millisec::time_duration(0, 4, 5, 3));
-    EXPECT_EQ(d.getMaxSampleAge().second, millisec::time_duration(0, 4, 5, 3));
+    EXPECT_EQ(a.getMaxSampleAge().second, dur453);
+    EXPECT_EQ(b.getMaxSampleAge().second, dur453);
+    EXPECT_EQ(c.getMaxSampleAge().second, dur453);
+    EXPECT_EQ(d.getMaxSampleAge().second, dur453);
 
     EXPECT_EQ(a.getMaxSampleCount().first, false);
     EXPECT_EQ(b.getMaxSampleCount().first, false);
@@ -480,12 +493,12 @@ TEST_F(ObservationTest, getLimits) {
 
 // Test checks whether timing is reported properly.
 TEST_F(ObservationTest, timers) {
-    ptime before = microsec_clock::local_time();
+    auto before = SampleClock::now();
     b.setValue(123.0); // Set it to a random value and record the time.
 
     // Allow a bit of imprecision. This test allows 500ms. That should be ok,
     // when running on virtual machines.
-    ptime after = before + milliseconds(500);
+    auto after = before + milliseconds(500);
 
     // Now wait some time. We want to confirm that the timestamp recorded is the
     // time the observation took place, not current time.
@@ -505,12 +518,12 @@ TEST_F(ObservationTest, timers) {
 TEST_F(ObservationTest, integerToJSON) {
     // String which contains first added sample
     std::string first_sample = ", [ 1234, \"" +
-        isc::util::ptimeToText(a.getInteger().second) + "\" ] ]";
+        isc::util::clockToText(a.getInteger().second) + "\" ] ]";
 
     a.setValue(static_cast<int64_t>(1234));
 
     std::string exp = "[ [ 1234, \"" +
-        isc::util::ptimeToText(a.getInteger().second) + "\" ]" + first_sample;
+        isc::util::clockToText(a.getInteger().second) + "\" ]" + first_sample;
 
     std::cout << a.getJSON()->str() << std::endl;
     EXPECT_EQ(exp, a.getJSON()->str());
@@ -523,7 +536,7 @@ TEST_F(ObservationTest, integerToJSON) {
 TEST_F(ObservationTest, floatToJSON) {
     // String which contains first added sample
     std::string first_sample = ", [ 12.34, \"" +
-        isc::util::ptimeToText(b.getFloat().second) + "\" ] ]";
+        isc::util::clockToText(b.getFloat().second) + "\" ] ]";
 
     // Let's use a value that converts easily to floating point.
     // No need to deal with infinite fractions in binary systems.
@@ -531,7 +544,7 @@ TEST_F(ObservationTest, floatToJSON) {
     b.setValue(1234.5);
 
     std::string exp = "[ [ 1234.5, \"" +
-        isc::util::ptimeToText(b.getFloat().second) + "\" ]" + first_sample;
+        isc::util::clockToText(b.getFloat().second) + "\" ]" + first_sample;
 
     std::cout << b.getJSON()->str() << std::endl;
     EXPECT_EQ(exp, b.getJSON()->str());
@@ -542,14 +555,14 @@ TEST_F(ObservationTest, floatToJSON) {
 // details.
 TEST_F(ObservationTest, durationToJSON) {
     // String which contains first added sample
-    std::string first_sample = ", [ \"01:02:03.000004\", \"" +
-        isc::util::ptimeToText(c.getDuration().second) + "\" ] ]";
+    std::string first_sample = ", [ \"01:02:03.004000\", \"" +
+        isc::util::clockToText(c.getDuration().second) + "\" ] ]";
 
     // 1 hour 2 minutes 3 seconds and 4 milliseconds
-    c.setValue(time_duration(1, 2, 3, 4));
+    c.setValue(dur1234);
 
-    std::string exp = "[ [ \"01:02:03.000004\", \"" +
-        isc::util::ptimeToText(c.getDuration().second) + "\" ]" + first_sample;
+    std::string exp = "[ [ \"01:02:03.004000\", \"" +
+        isc::util::clockToText(c.getDuration().second) + "\" ]" + first_sample;
 
     std::cout << c.getJSON()->str() << std::endl;
     EXPECT_EQ(exp, c.getJSON()->str());
@@ -561,12 +574,12 @@ TEST_F(ObservationTest, durationToJSON) {
 TEST_F(ObservationTest, stringToJSON) {
     // String which contains first added sample
     std::string first_sample = ", [ \"1234\", \"" +
-        isc::util::ptimeToText(d.getString().second) + "\" ] ]";
+        isc::util::clockToText(d.getString().second) + "\" ] ]";
 
     d.setValue("Lorem ipsum dolor sit amet");
 
     std::string exp = "[ [ \"Lorem ipsum dolor sit amet\", \"" +
-        isc::util::ptimeToText(d.getString().second) + "\" ]" + first_sample;
+        isc::util::clockToText(d.getString().second) + "\" ]" + first_sample;
 
     std::cout << d.getJSON()->str() << std::endl;
     EXPECT_EQ(exp, d.getJSON()->str());
@@ -576,7 +589,7 @@ TEST_F(ObservationTest, stringToJSON) {
 TEST_F(ObservationTest, reset) {
     EXPECT_NO_THROW(a.addValue(static_cast<int64_t>(5678)));
     EXPECT_NO_THROW(b.addValue(56.78));
-    EXPECT_NO_THROW(c.addValue(millisec::time_duration(5, 6, 7, 8)));
+    EXPECT_NO_THROW(c.addValue(dur5678));
     EXPECT_NO_THROW(d.addValue("fiveSixSevenEight"));
 
     a.reset(); // integer
@@ -586,7 +599,7 @@ TEST_F(ObservationTest, reset) {
 
     EXPECT_EQ(0, a.getInteger().first);
     EXPECT_EQ(0.0, b.getFloat().first);
-    EXPECT_EQ(time_duration(0, 0, 0, 0), c.getDuration().first);
+    EXPECT_EQ(StatsDuration::zero(), c.getDuration().first);
     EXPECT_EQ("", d.getString().first);
 
     ASSERT_EQ(a.getSize(), 1);
@@ -603,4 +616,4 @@ TEST_F(ObservationTest, names) {
     EXPECT_EQ("delta", d.getName());
 }
 
-};
+}
